<?php

/*
 * In this file are consolidated the object class definitions and supporting
 * functions in general to make this web site function. Much of the functionality
 * is focused upon supporting a local user authentication capability and an online
 * note taking/ehancement capability.
 *
 * Loading this file will NOT create any HTML output.
 *
 * Ross Beveridge August 3, 2012
 * Ross Beveridge Last update February 1, 2013
 * Chris Wilcox Removed authentication December 31, 2013
 * Jaime Ruiz Added $relPath variable Jan 14, 2014
 * Felipe Volpatto Added methods to debug; Updated to accept .csv files Jun 09, 2015
 */

/*
 * =============================================================================
 * URL Support
 *
 * Global vars that help write navigation and css urls releative to a page
 */
if (! isset ( $pgLevel ))
	$pageLevel = 0;
switch ($pgLevel) {
	case 1 :
		$relPath = "../";
		break;
	case 2 :
		$relPath = "../../";
		break;
	case 3 :
		$relPath = "../../../";
		break;
	default :
		$relPath = "./";
}
/*
 * =============================================================================
 * HOMEPAGE AND SYLLABUS SUPPORT
 *
 * The function below creates the whowhatwhere division used to summarize
 * the logistical basics of the course using information drawn from the
 * configuration file.
 */
function echoWhoWhatWhereDiv($vitals) {
	echo '<div id="whowhatwhere">' . "\n";
	echo '<dl>' . "\n";
	echo '<dt>Instructor:</dt>' . "\n";
	if (empty ( $vitals->instructor_home )) {
		echo "<dd> $vitals->instructor_name <br />\n";
	} else {
		echo "<dd><a href=\"$vitals->instructor_home\"> $vitals->instructor_name </a><br />\n";
	}
	echo "Office: $vitals->instructor_office <br />\n";
	echo "Office Hours: $vitals->instructor_hours";
	if (! empty ( $vitals->instructor_mail )) {
		echo "<br />\nEmail: $vitals->instructor_mail";
	}
	echo "\n</dd>\n";
	if (! empty ( $vitals->gta_name )) {
		echo "<dt>GTA:</dt>\n";
		if (empty ( $vitals->gta_home )) {
			echo "<dd>$vitals->gta_name <br /> \n";
		} else {
			echo "<dd><a href=\"$vitals->gta_home\"> $vitals->gta_name </a><br />\n";
		}
		echo "Office: $vitals->gta_office <br />\n";
		echo "Office Hours: $vitals->gta_hours";
		if (! empty ( $vitals->gta_mail )) {
			echo "<br />\nEmail: $vitals->gta_mail";
		}
		echo "<br />\n</dd>\n";
	}
	echo "<dt>Lecture Time and Place:</dt>\n";
	echo "<dd>$vitals->lecture_time, $vitals->lecture_days, $vitals->lecture_place </dd>\n";
	
	if (! empty ( $vitals->recit1_time )) {
		echo "<dt>Recitation 1 Time and Place:</dt>\n";
		echo "<dd>$vitals->recit1_time, $vitals->recit1_days, $vitals->recit1_place </dd>\n";
	}
	if (! empty ( $vitals->recit2_time )) {
		echo "<dt>Recitation 2 Time and Place:</dt>\n";
		echo "<dd>$vitals->recit2_time, $vitals->recit2_days, $vitals->recit2_place </dd>\n";
	}
	if (! empty ( $vitals->recit3_time )) {
		echo "<dt>Recitation 3 Time and Place:</dt>\n";
		echo "<dd>$vitals->recit3_time, $vitals->recit3_days, $vitals->recit3_place </dd>\n";
	}
	
	echo "</dl>\n</div>\n";
	echo '<!-- End of Who What Where Division -->' . "\n";
}

/*
 * =============================================================================
 * FILE SYSTEM SUPPORT
 *
 * Deleting a file in response to a web page action worries me, so instead
 * files being replaced with updated versions are first copied to a new
 * file with the old name and 'depreicated' and a unix time stamp affixed
 * to them.
 */

// TODO
// Updated to accept .csv file
function depricateTxtFileWhenExists($fname) {
	$f_suffix = substr ( $fname, - 4 );
	
	if (($f_suffix != '.txt') && ($f_suffix != '.csv') && ($f_suffix != '.tsv')) {
		echo "Attempt to rename (depricate) file $fname failed because file suffix is neither txt or tsv.\n";
		exit ();
	}
	if (file_exists ( $fname )) {
		$tnow = new DateTime ( 'now', new DateTimeZone ( 'America/Denver' ) );
		$tstamp = $tnow->format ( 'U' );
		$new_ending = '_depricated_' . $tstamp . $f_suffix;
		$depname = str_replace ( $f_suffix, $new_ending, $fname );
		rename ( $fname, $depname );
	}
}

/*
 * ================================================================================
 * There are pages, for example submitting notes to slides, where a user must be
 * logged in to access the functionality. This function supports that behavior.
 */
function diePolitelyIfNotLoggedIn() {
	if ($_SESSION ['userLast'] == 'Guest') {
		echo '<p>You must be logged in before you will see the functions available on this page.</p>' . "\n";
		echo '</div>' . "\n" . '<!-- End of contents -->' . "\n";
		include ("ztools/common_terminate.php");
		exit ();
	}
}

/*
 * ===============================================================================
 * As CS Roo developes the inclusion of administration function will make it more
 * useful. So far the only admin function is to create a blank progress/spreadsheet
 * tailored to the start date and MWF vs TR setting of the cours. At some point
 * web editing of the progress page would be a nice addition.
 */
function diePolitelyIfNotAdmin() {
	if (($_SESSION ['userStatus'] != 'admin')) {
		echo '<p>You must be logged in as an adminstrator before you will see the functions available on this page.</p>' . "\n";
		echo '</div>' . "\n" . '<!-- End of contents -->' . "\n";
		include ("ztools/common_terminate.php");
		exit ();
	}
}

/*
 * It is important to properly destroy cookies and clear the sessions array when a user logs out.
 *
 * The following code is based upon an example in the PHP documentation for session_destroy
 */
function properlyCleanUpWhenLoggingOut() {
	// Unset all of the session variables.
	$_SESSION = array ();
	
	// If it's desired to kill the session, also delete the session cookie.
	// Note: This will destroy the session, and not just the session data!
	if (ini_get ( "session.use_cookies" )) {
		$params = session_get_cookie_params ();
		setcookie ( session_name (), '', time () - 42000, $params ["path"], $params ["domain"], $params ["secure"], $params ["httponly"] );
	}
	
	// Finally, destroy the session.
	session_destroy ();
}

// Felipe
/*
 * Generate a better view of an array
 * @author Felipe Volpatto <felipevolpatto@gmail.com>
 */
function debugArray($array) {
	echo '<pre>';
	print_r ( $array );
	echo '</pre>';
}

/*
 * Generate a better view of an object
 * @author Felipe Volpatto <felipevolpatto@gmail.com>
 */
function debugObject($object) {
	echo '<pre>';
	var_dump ( $object );
	echo '</pre>';
}

/*
 * Indicates whether the string is empty or null.
 * @author Felipe Volpatto <felipevolpatto@gmail.com>
 */
function isNullOrEmpty($string) {
	return (! isset ( $string ) || $string == "");
}

?>
 